@@ -2,11 +2,10 @@ from pg8000.converters import (
     BIGINTEGER, BINARY, BOOLEAN, BOOLEAN_ARRAY, BYTES, Binary, CHAR,
     CHAR_ARRAY, DATE, DATETIME, DECIMAL, DECIMAL_ARRAY, Date, DateFromTicks,
     FLOAT, FLOAT_ARRAY, INET, INT2VECTOR, INTEGER, INTEGER_ARRAY, INTERVAL,
-    JSON, JSONB, MACADDR, NAME, NAME_ARRAY, NULLTYPE, NUMBER, OID, PGEnum,
-    PGInterval, PGJson, PGJsonb, PGText, PGTsvector, PGVarchar, ROWID, STRING,
-    TEXT, TEXT_ARRAY, TIME, TIMEDELTA, TIMESTAMP, TIMESTAMPTZ, Time,
-    TimeFromTicks, Timestamp, TimestampFromTicks, UNKNOWN, UUID_TYPE, VARCHAR,
-    VARCHAR_ARRAY, XID)
+    JSON, JSONB, MACADDR, NAME, NAME_ARRAY, NULLTYPE, NUMBER, OID, PGInterval,
+    ROWID, STRING, TEXT, TEXT_ARRAY, TIME, TIMEDELTA, TIMESTAMP, TIMESTAMPTZ,
+    Time, TimeFromTicks, Timestamp, TimestampFromTicks, UNKNOWN, UUID_TYPE,
+    VARCHAR, VARCHAR_ARRAY, XID)
 from pg8000.core import Connection, Cursor
 from pg8000.exceptions import (
     DataError, DatabaseError, Error, IntegrityError, InterfaceError,
@@ -84,11 +83,10 @@ __all__ = [
     Warning, DataError, DatabaseError, connect, InterfaceError,
     ProgrammingError, Error, OperationalError, IntegrityError, InternalError,
     NotSupportedError, Connection, Cursor, Binary, Date, DateFromTicks, Time,
-    TimeFromTicks, Timestamp, TimestampFromTicks, BINARY, PGInterval, PGEnum,
-    PGJson, PGJsonb, PGTsvector, PGText, PGVarchar, STRING, NUMBER, DATETIME,
-    TIME, BOOLEAN, INTEGER, BIGINTEGER, INTERVAL, JSON, JSONB, UNKNOWN,
-    NULLTYPE, ROWID, BOOLEAN_ARRAY, BYTES, CHAR, CHAR_ARRAY, DATE, DECIMAL,
-    DECIMAL_ARRAY, FLOAT, FLOAT_ARRAY, INET, INT2VECTOR, INTEGER_ARRAY,
-    MACADDR, NAME, NAME_ARRAY, OID, TEXT, TEXT_ARRAY, TIMEDELTA, TIMESTAMP,
-    TIMESTAMPTZ, UUID_TYPE, VARCHAR, VARCHAR_ARRAY, XID
+    TimeFromTicks, Timestamp, TimestampFromTicks, BINARY, PGInterval, STRING,
+    NUMBER, DATETIME, TIME, BOOLEAN, INTEGER, BIGINTEGER, INTERVAL, JSON,
+    JSONB, UNKNOWN, NULLTYPE, ROWID, BOOLEAN_ARRAY, BYTES, CHAR, CHAR_ARRAY,
+    DATE, DECIMAL, DECIMAL_ARRAY, FLOAT, FLOAT_ARRAY, INET, INT2VECTOR,
+    INTEGER_ARRAY, MACADDR, NAME, NAME_ARRAY, OID, TEXT, TEXT_ARRAY, TIMEDELTA,
+    TIMESTAMP, TIMESTAMPTZ, UUID_TYPE, VARCHAR, VARCHAR_ARRAY, XID
 ]
